@@ -140,7 +140,7 @@ some_features_are_off <- function(features) {
   # `features` is a named logical vector (as in arrow_info()$capabilities)
   # Let's exclude some less relevant ones
   # jemalloc is only included because it is sometimes disabled in our build process
-  blocklist <- c("lzo", "bz2", "brotli", "substrait", "jemalloc")
+  blocklist <- c("lzo", "bz2", "brotli", "substrait", "jemalloc", "gcs")
   # Return TRUE if any of the other features are FALSE
   !all(features[setdiff(names(features), blocklist)])
 }
@@ -157,11 +157,14 @@ print.arrow_info <- function(x, ...) {
     cat("\n")
   }
   cat("Arrow package version: ", format(x$version), "\n\n", sep = "")
-  print_key_values("Capabilities", c(
-    x$capabilities,
-    jemalloc = "jemalloc" %in% x$memory_pool$available_backends,
-    mimalloc = "mimalloc" %in% x$memory_pool$available_backends
-  ))
+  print_key_values(
+    "Capabilities",
+    c(
+      x$capabilities,
+      jemalloc = "jemalloc" %in% x$memory_pool$available_backends,
+      mimalloc = "mimalloc" %in% x$memory_pool$available_backends
+    )
+  )
   if (some_features_are_off(x$capabilities) && identical(tolower(Sys.info()[["sysname"]]), "linux")) {
     # Only on linux because (e.g.) we disable certain features on purpose on rtools35
     cat(
@@ -177,22 +180,31 @@ print.arrow_info <- function(x, ...) {
   format_bytes <- function(b, units = "auto", digits = 2L, ...) {
     format(structure(b, class = "object_size"), units = units, digits = digits, ...)
   }
-  print_key_values("Memory", c(
-    Allocator = x$memory_pool$backend_name,
-    # utils:::format.object_size is not properly vectorized
-    Current = format_bytes(x$memory_pool$bytes_allocated, ...),
-    Max = format_bytes(x$memory_pool$max_memory, ...)
-  ))
-  print_key_values("Runtime", c(
-    `SIMD Level` = x$runtime_info$simd_level,
-    `Detected SIMD Level` = x$runtime_info$detected_simd_level
-  ))
-  print_key_values("Build", c(
-    `C++ Library Version` = x$build_info$cpp_version,
-    `C++ Compiler` = x$build_info$cpp_compiler,
-    `C++ Compiler Version` = x$build_info$cpp_compiler_version,
-    `Git ID` = x$build_info$git_id
-  ))
+  print_key_values(
+    "Memory",
+    c(
+      Allocator = x$memory_pool$backend_name,
+      # utils:::format.object_size is not properly vectorized
+      Current = format_bytes(x$memory_pool$bytes_allocated, ...),
+      Max = format_bytes(x$memory_pool$max_memory, ...)
+    )
+  )
+  print_key_values(
+    "Runtime",
+    c(
+      `SIMD Level` = x$runtime_info$simd_level,
+      `Detected SIMD Level` = x$runtime_info$detected_simd_level
+    )
+  )
+  print_key_values(
+    "Build",
+    c(
+      `C++ Library Version` = x$build_info$cpp_version,
+      `C++ Compiler` = x$build_info$cpp_compiler,
+      `C++ Compiler Version` = x$build_info$cpp_compiler_version,
+      `Git ID` = x$build_info$git_id
+    )
+  )
 
   invisible(x)
 }
