@@ -35,7 +35,9 @@ arrow_eval <- function(expr, mask) {
     # for better error messages
     msg <- conditionMessage(e)
     arrow_debug <- getOption("arrow.debug", FALSE)
-    if (arrow_debug) print(msg)
+    if (arrow_debug) {
+      print(msg)
+    }
 
     # A few cases:
     # 1. Evaluation raised one of our error classes. Add the expr as the call
@@ -69,7 +71,6 @@ arrow_eval <- function(expr, mask) {
       arrow_not_supported(.actual_msg = msg, call = expr)
     }
 
-
     # 5. Otherwise, we're not sure why this errored: it's not an error we raised
     #    explicitly. We'll assume it's because the function it calls isn't
     #    supported in arrow, and retry with dplyr may help.
@@ -182,9 +183,7 @@ i18ize_error_messages <- function() {
 #' include `call` to provide the call or expression that caused the error, and
 #' `body` to provide additional context about the error.
 #' @keywords internal
-arrow_not_supported <- function(msg,
-                                .actual_msg = paste(msg, "not supported in Arrow"),
-                                ...) {
+arrow_not_supported <- function(msg, .actual_msg = paste(msg, "not supported in Arrow"), ...) {
   abort(.actual_msg, class = "arrow_not_supported", use_cli_format = TRUE, ...)
 }
 
