@@ -23,22 +23,20 @@
 #undef Free
 
 #include <cpp11.hpp>
-#include <cpp11/altrep.hpp>
 
 #include "./nameof.h"
 
-// borrowed from enc package
-// because R does not make these macros available (i.e. from Defn.h)
-#define UTF8_MASK (1 << 3)
-#define ASCII_MASK (1 << 6)
-
-#define IS_ASCII(x) (LEVELS(x) & ASCII_MASK)
-#define IS_UTF8(x) (LEVELS(x) & UTF8_MASK)
-
-// For context, see:
-// https://github.com/r-devel/r-svn/blob/6418faeb6f5d87d3d9b92b8978773bc3856b4b6f/src/main/altrep.c#L37
-#define ALTREP_CLASS_SERIALIZED_CLASS(x) ATTRIB(x)
-#define ALTREP_SERIALIZED_CLASS_PKGSYM(x) CADR(x)
+// Simple dcheck that doesn't use assert (i.e., won't crash the R session)
+// Condition this on our own debug flag to avoid this ending up in any CRAN
+// checks.
+#if defined(ARROW_R_DEBUG)
+#define ARROW_R_DCHECK(EXPR)                                              \
+  do {                                                                    \
+    if (!(EXPR)) Rf_error("Failed DCHECK: %s evaluated to false", #EXPR); \
+  } while (false)
+#else
+#define ARROW_R_DCHECK(EXPR)
+#endif
 
 #if (R_VERSION < R_Version(3, 5, 0))
 #define LOGICAL_RO(x) ((const int*)LOGICAL(x))
@@ -51,6 +49,16 @@
 #define DATAPTR(x) (void*)STRING_PTR(x)
 #endif
 
+// R_altrep_class_name and R_altrep_class_package don't exist before R 4.6
+#if R_VERSION < R_Version(4, 6, 0)
+inline SEXP R_altrep_class_name(SEXP x) {
+  return ALTREP(x) ? CAR(ATTRIB(ALTREP_CLASS(x))) : R_NilValue;
+}
+inline SEXP R_altrep_class_package(SEXP x) {
+  return ALTREP(x) ? CADR(ATTRIB(ALTREP_CLASS(x))) : R_NilValue;
+}
+#endif
+
 namespace arrow {
 namespace r {
 
@@ -121,19 +129,11 @@ class complexs {
 // functions that need to be called from an unwind_protect()
 namespace unsafe {
 
-inline const char* utf8_string(SEXP s) {
-  if (!IS_UTF8(s) && !IS_ASCII(s)) {
-    return Rf_translateCharUTF8(s);
-  } else {
-    return CHAR(s);
-  }
-}
+inline const char* utf8_string(SEXP s) { return Rf_translateCharUTF8(s); }
 
 inline R_xlen_t r_string_size(SEXP s) {
   if (s == NA_STRING) {
     return 0;
-  } else if (IS_ASCII(s) || IS_UTF8(s)) {
-    return XLENGTH(s);
   } else {
     return strlen(Rf_translateCharUTF8(s));
   }
@@ -142,7 +142,13 @@ inline R_xlen_t r_string_size(SEXP s) {
 }  // namespace unsafe
 
 inline SEXP utf8_strings(SEXP x) {
-  return cpp11::unwind_protect([x] {
+  return cpp11::unwind_protect([&] {
+    // ensure that x is not actually altrep first this also ensures that
+    // x is not altrep even after it is materialized
+    bool was_altrep = ALTREP(x);
+    if (was_altrep) {
+      x = PROTECT(Rf_duplicate(x));
+    }
     R_xlen_t n = XLENGTH(x);
 
     // if `x` is an altrep of some sort, this will
@@ -152,10 +158,13 @@ inline SEXP utf8_strings(SEXP x) {
 
     for (R_xlen_t i = 0; i < n; i++, ++p_x) {
       SEXP s = *p_x;
-      if (s != NA_STRING && !IS_UTF8(s) && !IS_ASCII(s)) {
+      if (s != NA_STRING) {
         SET_STRING_ELT(x, i, Rf_mkCharCE(Rf_translateCharUTF8(s), CE_UTF8));
       }
     }
+    if (was_altrep) {
+      UNPROTECT(1);
+    }
     return x;
   });
 }
@@ -382,9 +391,17 @@ SEXP to_r6(const std::shared_ptr<T>& ptr, const char* r6_class_name) {
   cpp11::external_pointer<std::shared_ptr<T>> xp(new std::shared_ptr<T>(ptr));
   SEXP r6_class = Rf_install(r6_class_name);
 
+// R_existsVarInFrame doesn't exist before R 4.2, so we need to fall back to
+// Rf_findVarInFrame3 if it is not defined.
+#if R_VERSION >= R_Version(4, 2, 0)
+  if (!R_existsVarInFrame(arrow::r::ns::arrow, r6_class)) {
+    cpp11::stop("No arrow R6 class named '%s'", r6_class_name);
+  }
+#else
   if (Rf_findVarInFrame3(arrow::r::ns::arrow, r6_class, FALSE) == R_UnboundValue) {
     cpp11::stop("No arrow R6 class named '%s'", r6_class_name);
   }
+#endif
 
   // make call:  <symbol>$new(<x>)
   SEXP call = PROTECT(Rf_lang3(R_DollarSymbol, r6_class, arrow::r::symbols::new_));
@@ -465,7 +482,7 @@ inline SEXP as_sexp(r_vec_size size) {
   if (x > std::numeric_limits<int>::max()) {
     return Rf_ScalarReal(x);
   } else {
-    return Rf_ScalarInteger(x);
+    return Rf_ScalarInteger(static_cast<int>(x));
   }
 }
 
